pub struct DummyFunctionCallLibfunc {}Expand description
Libfunc to replace function calls in size estimation.
The libfunc consumes the function arguments and returns the function return values.
The ap_change and signature are encoded in the generic arguments, see
try_extract_dummy_func_info for details.